# lingo - payment and billing system
# Copyright (C) 2022  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.urls import reverse
from django.views.generic import CreateView, DeleteView, DetailView, ListView, TemplateView, UpdateView

from lingo.invoicing.models import Regie


class HomeView(TemplateView):
    template_name = 'lingo/invoicing/manager_home.html'


home = HomeView.as_view()


class RegiesListView(ListView):
    template_name = 'lingo/invoicing/manager_regie_list.html'
    model = Regie


regies_list = RegiesListView.as_view()


class RegieAddView(CreateView):
    template_name = 'lingo/invoicing/manager_regie_form.html'
    model = Regie
    fields = ['label', 'description', 'cashier_role']

    def get_success_url(self):
        return reverse('lingo-manager-invoicing-regie-detail', args=[self.object.pk])


regie_add = RegieAddView.as_view()


class RegieDetailView(DetailView):
    template_name = 'lingo/invoicing/manager_regie_detail.html'
    model = Regie

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context['regie'] = self.object
        return context


regie_detail = RegieDetailView.as_view()


class RegieEditView(UpdateView):
    template_name = 'lingo/invoicing/manager_regie_form.html'
    model = Regie
    fields = ['label', 'description', 'cashier_role']

    def get_success_url(self):
        return reverse('lingo-manager-invoicing-regie-detail', args=[self.object.pk])


regie_edit = RegieEditView.as_view()


class RegieDeleteView(DeleteView):
    template_name = 'lingo/manager_confirm_delete.html'
    model = Regie

    def get_success_url(self):
        return reverse('lingo-manager-invoicing-regie-list')


regie_delete = RegieDeleteView.as_view()
